==> vmaid-2.2.0.tar.gz: vmaid-2.2.0/w32loader/commdlg.h <==
/*
    w32loader
    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef __COMMDLG_H__
#define __COMMDLG_H__


#include "w32ldr.h"


G_BEGIN_DECLS


#include "gdi32.h"

#define CF_SCREENFONTS          0x00000001
#define CF_PRINTERFONTS         0x00000002
#define CF_BOTH                 (CF_SCREENFONTS|CF_PRINTERFONTS)
#define CF_SHOWHELP             0x00000004
#define CF_ENABLEHOOK           0x00000008
#define CF_ENABLETEMPLATE       0x00000010
#define CF_ENABLETEMPLATEHANDLE 0x00000020
#define CF_INITTOLOGFONTSTRUCT  0x00000040
#define CF_USESTYLE             0x00000080
#define CF_EFFECTS              0x00000100
#define CF_APPLY                0x00000200
#define CF_ANSIONLY             0x00000400
#define CF_SCRIPTSONLY          CF_ANSIONLY
#define CF_NOVECTORFONTS        0x00000800
#define CF_NOOEMFONTS           CF_NOVECTORFONTS
#define CF_NOSIMULATIONS        0x00001000
#define CF_LIMITSIZE            0x00002000
#define CF_FIXEDPITCHONLY       0x00004000
#define CF_WYSIWYG              0x00008000
#define CF_FORCEFONTEXIST       0x00010000
#define CF_SCALABLEONLY         0x00020000
#define CF_TTONLY               0x00040000
#define CF_NOFACESEL            0x00080000
#define CF_NOSTYLESEL           0x00100000
#define CF_NOSIZESEL            0x00200000
#define CF_SELECTSCRIPT         0x00400000
#define CF_NOSCRIPTSEL          0x00800000
#define CF_NOVERTFONTS          0x01000000
#define SIMULATED_FONTTYPE 0x8000
#define PRINTER_FONTTYPE   0x4000
#define SCREEN_FONTTYPE    0x2000
typedef UINT (CALLBACK *LPCFHOOKPROC)(HWND, UINT, WPARAM, LPARAM);
#include "pshpack1.h"
typedef struct _CHOOSEFONTA
{
  UINT lStructSize;
  HWND hwndOwner;
  HDC hDC;
  LPLOGFONTA lpLogFont;
  INT iPointSize;
  DWORD Flags;
  COLORREF rgbColors;
  LPARAM lCustData;
  LPCFHOOKPROC lpfnHook;
  LPCSTR lpTemplateName;
  HINSTANCE hInstance;
  LPSTR lpszStyle;
  WORD nFontType;
  WORD ___MISSING_ALIGNMENT__;
  INT nSizeMin;
  INT nSizeMax;
} CHOOSEFONTA, *PCHOOSEFONTA, *LPCHOOSEFONTA;
typedef struct _CHOOSEFONTW
{
  UINT lStructSize;
  HWND hwndOwner;
  HDC hDC;
  LPLOGFONTW lpLogFont;
  INT iPointSize;
  DWORD Flags;
  COLORREF rgbColors;
  LPARAM lCustData;
  LPCFHOOKPROC lpfnHook;
  LPCWSTR lpTemplateName;
  HINSTANCE hInstance;
  LPWSTR lpszStyle;
  WORD nFontType;
  WORD ___MISSING_ALIGNMENT__;
  INT nSizeMin;
  INT nSizeMax;
} CHOOSEFONTW, *PCHOOSEFONTW, *LPCHOOSEFONTW;
#include "poppack.h"
#ifdef UNICODE
# define CHOOSEFONT CHOOSEFONTW
# define PCHOOSEFONT PCHOOSEFONTW
# define LPCHOOSEFONT LPCHOOSEFONTW
#else /* not UNICODE */
# define CHOOSEFONT CHOOSEFONTA
# define PCHOOSEFONT PCHOOSEFONTA
# define LPCHOOSEFONT LPCHOOSEFONTA
#endif /* not UNICODE */

#define OFN_READONLY             0x00000001
#define OFN_OVERWRITEPROMPT      0x00000002
#define OFN_HIDEREADONLY         0x00000004
#define OFN_NOCHANGEDIR          0x00000008
#define OFN_SHOWHELP             0x00000010
#define OFN_ENABLEHOOK           0x00000020
#define OFN_ENABLETEMPLATE       0x00000040
#define OFN_ENABLETEMPLATEHANDLE 0x00000080
#define OFN_NOVALIDATE           0x00000100
#define OFN_ALLOWMULTISELECT     0x00000200
#define OFN_EXTENSIONDIFFERENT   0x00000400
#define OFN_PATHMUSTEXIST        0x00000800
#define OFN_FILEMUSTEXIST        0x00001000
#define OFN_CREATEPROMPT         0x00002000
#define OFN_SHAREAWARE           0x00004000
#define OFN_NOREADONLYRETURN     0x00008000
#define OFN_NOTESTFILECREATE     0x00010000
#define OFN_NONETWORKBUTTON      0x00020000
#define OFN_NOLONGNAMES          0x00040000
#define OFN_SHAREFALLTHROUGH     2
#define OFN_SHARENOWARN          1
#define OFN_SHAREWARN            0
typedef UINT (CALLBACK *LPOFNHOOKPROC)(HWND, UINT, WPARAM, LPARAM);
typedef struct _OPENFILENAMEA
{
  DWORD lStructSize;
  HWND hwndOwner;
  HINSTANCE hInstance;
  LPCSTR lpstrFilter;
  LPSTR lpstrCustomFilter;
  DWORD nMaxCustFilter;
  DWORD nFilterIndex;
  LPSTR lpstrFile;
  DWORD nMaxFile;
  LPSTR lpstrFileTitle;
  DWORD nMaxFileTitle;
  LPCSTR lpstrInitialDir;
  LPCSTR lpstrTitle;
  DWORD Flags;
  WORD nFileOffset;
  WORD nFileExtension;
  LPCSTR lpstrDefExt;
  LPARAM lCustData;
  LPOFNHOOKPROC lpfnHook;
  LPCSTR lpTemplateName;
} OPENFILENAMEA, *POPENFILENAMEA, *LPOPENFILENAMEA;
typedef struct _OPENFILENAMEW
{
  DWORD lStructSize;
  HWND hwndOwner;
  HINSTANCE hInstance;
  LPCWSTR lpstrFilter;
  LPWSTR lpstrCustomFilter;
  DWORD nMaxCustFilter;
  DWORD nFilterIndex;
  LPWSTR lpstrFile;
  DWORD nMaxFile;
  LPWSTR lpstrFileTitle;
  DWORD nMaxFileTitle;
  LPCWSTR lpstrInitialDir;
  LPCWSTR lpstrTitle;
  DWORD Flags;
  WORD nFileOffset;
  WORD nFileExtension;
  LPCWSTR lpstrDefExt;
  LPARAM lCustData;
  LPOFNHOOKPROC lpfnHook;
  LPCWSTR lpTemplateName;
} OPENFILENAMEW, *POPENFILENAMEW, *LPOPENFILENAMEW;
#ifdef UNICODE
# define OPENFILENAME OPENFILENAMEW
# define POPENFILENAME POPENFILENAMEW
# define LPOPENFILENAME LPOPENFILENAMEW
#else /* not UNICODE */
# define OPENFILENAME OPENFILENAMEA
# define POPENFILENAME POPENFILENAMEA
# define LPOPENFILENAME LPOPENFILENAMEA
#endif /* not UNICODE */


extern W32LdrExport commdlg_exports[];


BOOL WINAPI ChooseFontA (LPCHOOSEFONTA lpcf);
BOOL WINAPI ChooseFontW (LPCHOOSEFONTW lpcf);
BOOL WINAPI GetOpenFileNameA (LPOPENFILENAMEA lpofn);
BOOL WINAPI GetOpenFileNameW (LPOPENFILENAMEW lpofn);
BOOL WINAPI GetSaveFileNameA (LPOPENFILENAMEA lpofn);
BOOL WINAPI GetSaveFileNameW (LPOPENFILENAMEW lpofn);


#ifdef UNICODE
# define ChooseFont ChooseFontW
# define GetOpenFileName GetOpenFileNameW
# define GetSaveFileName GetSaveFileNameW
#else /* not UNICODE*/
# define ChooseFont ChooseFontA
# define GetOpenFileName GetOpenFileNameA
# define GetSaveFileName GetSaveFileNameA
#endif /* not UNICODE */


G_END_DECLS


#endif /* __COMMDLG_H__ */

==> vmaid-2.2.3.tar.gz: vmaid-2.2.3/w32loader/commdlg.h <==
/*
    w32loader
    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef __COMMDLG_H__
#define __COMMDLG_H__


#include "w32ldr.h"


G_BEGIN_DECLS


#include "gdi32.h"

#define CF_SCREENFONTS          0x00000001
#define CF_PRINTERFONTS         0x00000002
#define CF_BOTH                 (CF_SCREENFONTS|CF_PRINTERFONTS)
#define CF_SHOWHELP             0x00000004
#define CF_ENABLEHOOK           0x00000008
#define CF_ENABLETEMPLATE       0x00000010
#define CF_ENABLETEMPLATEHANDLE 0x00000020
#define CF_INITTOLOGFONTSTRUCT  0x00000040
#define CF_USESTYLE             0x00000080
#define CF_EFFECTS              0x00000100
#define CF_APPLY                0x00000200
#define CF_ANSIONLY             0x00000400
#define CF_SCRIPTSONLY          CF_ANSIONLY
#define CF_NOVECTORFONTS        0x00000800
#define CF_NOOEMFONTS           CF_NOVECTORFONTS
#define CF_NOSIMULATIONS        0x00001000
#define CF_LIMITSIZE            0x00002000
#define CF_FIXEDPITCHONLY       0x00004000
#define CF_WYSIWYG              0x00008000
#define CF_FORCEFONTEXIST       0x00010000
#define CF_SCALABLEONLY         0x00020000
#define CF_TTONLY               0x00040000
#define CF_NOFACESEL            0x00080000
#define CF_NOSTYLESEL           0x00100000
#define CF_NOSIZESEL            0x00200000
#define CF_SELECTSCRIPT         0x00400000
#define CF_NOSCRIPTSEL          0x00800000
#define CF_NOVERTFONTS          0x01000000
#define SIMULATED_FONTTYPE 0x8000
#define PRINTER_FONTTYPE   0x4000
#define SCREEN_FONTTYPE    0x2000
typedef UINT (CALLBACK *LPCFHOOKPROC)(HWND, UINT, WPARAM, LPARAM);
#include "pshpack1.h"
typedef struct _CHOOSEFONTA
{
  UINT lStructSize;
  HWND hwndOwner;
  HDC hDC;
  LPLOGFONTA lpLogFont;
  INT iPointSize;
  DWORD Flags;
  COLORREF rgbColors;
  LPARAM lCustData;
  LPCFHOOKPROC lpfnHook;
  LPCSTR lpTemplateName;
  HINSTANCE hInstance;
  LPSTR lpszStyle;
  WORD nFontType;
  WORD ___MISSING_ALIGNMENT__;
  INT nSizeMin;
  INT nSizeMax;
} CHOOSEFONTA, *PCHOOSEFONTA, *LPCHOOSEFONTA;
typedef struct _CHOOSEFONTW
{
  UINT lStructSize;
  HWND hwndOwner;
  HDC hDC;
  LPLOGFONTW lpLogFont;
  INT iPointSize;
  DWORD Flags;
  COLORREF rgbColors;
  LPARAM lCustData;
  LPCFHOOKPROC lpfnHook;
  LPCWSTR lpTemplateName;
  HINSTANCE hInstance;
  LPWSTR lpszStyle;
  WORD nFontType;
  WORD ___MISSING_ALIGNMENT__;
  INT nSizeMin;
  INT nSizeMax;
} CHOOSEFONTW, *PCHOOSEFONTW, *LPCHOOSEFONTW;
#include "poppack.h"
#ifdef UNICODE
# define CHOOSEFONT CHOOSEFONTW
# define PCHOOSEFONT PCHOOSEFONTW
# define LPCHOOSEFONT LPCHOOSEFONTW
#else /* not UNICODE */
# define CHOOSEFONT CHOOSEFONTA
# define PCHOOSEFONT PCHOOSEFONTA
# define LPCHOOSEFONT LPCHOOSEFONTA
#endif /* not UNICODE */

#define OFN_READONLY             0x00000001
#define OFN_OVERWRITEPROMPT      0x00000002
#define OFN_HIDEREADONLY         0x00000004
#define OFN_NOCHANGEDIR          0x00000008
#define OFN_SHOWHELP             0x00000010
#define OFN_ENABLEHOOK           0x00000020
#define OFN_ENABLETEMPLATE       0x00000040
#define OFN_ENABLETEMPLATEHANDLE 0x00000080
#define OFN_NOVALIDATE           0x00000100
#define OFN_ALLOWMULTISELECT     0x00000200
#define OFN_EXTENSIONDIFFERENT   0x00000400
#define OFN_PATHMUSTEXIST        0x00000800
#define OFN_FILEMUSTEXIST        0x00001000
#define OFN_CREATEPROMPT         0x00002000
#define OFN_SHAREAWARE           0x00004000
#define OFN_NOREADONLYRETURN     0x00008000
#define OFN_NOTESTFILECREATE     0x00010000
#define OFN_NONETWORKBUTTON      0x00020000
#define OFN_NOLONGNAMES          0x00040000
#define OFN_SHAREFALLTHROUGH     2
#define OFN_SHARENOWARN          1
#define OFN_SHAREWARN            0
typedef UINT (CALLBACK *LPOFNHOOKPROC)(HWND, UINT, WPARAM, LPARAM);
typedef struct _OPENFILENAMEA
{
  DWORD lStructSize;
  HWND hwndOwner;
  HINSTANCE hInstance;
  LPCSTR lpstrFilter;
  LPSTR lpstrCustomFilter;
  DWORD nMaxCustFilter;
  DWORD nFilterIndex;
  LPSTR lpstrFile;
  DWORD nMaxFile;
  LPSTR lpstrFileTitle;
  DWORD nMaxFileTitle;
  LPCSTR lpstrInitialDir;
  LPCSTR lpstrTitle;
  DWORD Flags;
  WORD nFileOffset;
  WORD nFileExtension;
  LPCSTR lpstrDefExt;
  LPARAM lCustData;
  LPOFNHOOKPROC lpfnHook;
  LPCSTR lpTemplateName;
} OPENFILENAMEA, *POPENFILENAMEA, *LPOPENFILENAMEA;
typedef struct _OPENFILENAMEW
{
  DWORD lStructSize;
  HWND hwndOwner;
  HINSTANCE hInstance;
  LPCWSTR lpstrFilter;
  LPWSTR lpstrCustomFilter;
  DWORD nMaxCustFilter;
  DWORD nFilterIndex;
  LPWSTR lpstrFile;
  DWORD nMaxFile;
  LPWSTR lpstrFileTitle;
  DWORD nMaxFileTitle;
  LPCWSTR lpstrInitialDir;
  LPCWSTR lpstrTitle;
  DWORD Flags;
  WORD nFileOffset;
  WORD nFileExtension;
  LPCWSTR lpstrDefExt;
  LPARAM lCustData;
  LPOFNHOOKPROC lpfnHook;
  LPCWSTR lpTemplateName;
} OPENFILENAMEW, *POPENFILENAMEW, *LPOPENFILENAMEW;
#ifdef UNICODE
# define OPENFILENAME OPENFILENAMEW
# define POPENFILENAME POPENFILENAMEW
# define LPOPENFILENAME LPOPENFILENAMEW
#else /* not UNICODE */
# define OPENFILENAME OPENFILENAMEA
# define POPENFILENAME POPENFILENAMEA
# define LPOPENFILENAME LPOPENFILENAMEA
#endif /* not UNICODE */


extern W32LdrExport w32ldr_commdlg_exports[];


BOOL WINAPI ChooseFontA (LPCHOOSEFONTA lpcf);
BOOL WINAPI ChooseFontW (LPCHOOSEFONTW lpcf);
BOOL WINAPI GetOpenFileNameA (LPOPENFILENAMEA lpofn);
BOOL WINAPI GetOpenFileNameW (LPOPENFILENAMEW lpofn);
BOOL WINAPI GetSaveFileNameA (LPOPENFILENAMEA lpofn);
BOOL WINAPI GetSaveFileNameW (LPOPENFILENAMEW lpofn);


#ifdef UNICODE
# define ChooseFont ChooseFontW
# define GetOpenFileName GetOpenFileNameW
# define GetSaveFileName GetSaveFileNameW
#else /* not UNICODE*/
# define ChooseFont ChooseFontA
# define GetOpenFileName GetOpenFileNameA
# define GetSaveFileName GetSaveFileNameA
#endif /* not UNICODE */


G_END_DECLS


#endif /* __COMMDLG_H__ */
